==> fish_3.0.2.orig.tar.gz: fish-3.0.2/src/tinyexpr.h <==
/*
 * TINYEXPR - Tiny recursive descent parser and evaluation engine in C
 *
 * Copyright (c) 2015, 2016 Lewis Van Winkle
 *
 * http://CodePlea.com
 *
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 * claim that you wrote the original software. If you use this software
 * in a product, an acknowledgement in the product documentation would be
 * appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 * misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 */

// This version was altered for inclusion in fish.

#ifndef __TINYEXPR_H__
#define __TINYEXPR_H__


#ifdef __cplusplus
extern "C" {
#endif


    typedef enum {
        TE_ERROR_NONE = 0,
        TE_ERROR_UNKNOWN_VARIABLE = 1,
        TE_ERROR_MISSING_CLOSING_PAREN = 2,
        TE_ERROR_MISSING_OPENING_PAREN = 3,
        TE_ERROR_TOO_FEW_ARGS = 4,
        TE_ERROR_TOO_MANY_ARGS = 5,
        TE_ERROR_MISSING_OPERATOR = 6,
        TE_ERROR_UNKNOWN = 7
    } te_error_type_t;


    typedef struct te_error_t {
        te_error_type_t type;
        int position;
    } te_error_t;

typedef struct te_expr {
    int type;
    union {double value; const double *bound; const void *function;};
    void *parameters[1];
} te_expr;


enum {
    TE_VARIABLE = 0,

    TE_FUNCTION0 = 8, TE_FUNCTION1, TE_FUNCTION2, TE_FUNCTION3,
    TE_FUNCTION4, TE_FUNCTION5, TE_FUNCTION6, TE_FUNCTION7,

    TE_FLAG_PURE = 32
};

typedef struct te_variable {
    const char *name;
    const void *address;
    int type;
    void *context;
} te_variable;



/* Parses the input expression, evaluates it, and frees it. */
/* Returns NaN on error. */
double te_interp(const char *expression, te_error_t *error);

/* Parses the input expression and binds variables. */
/* Returns NULL on error. */
te_expr *te_compile(const char *expression, const te_variable *variables, int var_count, te_error_t *error);

/* Evaluates the expression. */
double te_eval(const te_expr *n);

/* Prints debugging information on the syntax tree. */
void te_print(const te_expr *n);

/* Frees the expression. */
/* This is safe to call on NULL pointers. */
void te_free(te_expr *n);


#ifdef __cplusplus
}
#endif

#endif /*__TINYEXPR_H__*/

==> fish_3.1.2.orig.tar.gz: fish-3.1.2/src/tinyexpr.h <==
/*
 * TINYEXPR - Tiny recursive descent parser and evaluation engine in C
 *
 * Copyright (c) 2015, 2016 Lewis Van Winkle
 *
 * http://CodePlea.com
 *
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 * claim that you wrote the original software. If you use this software
 * in a product, an acknowledgement in the product documentation would be
 * appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 * misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 */

// This version was altered and ported to C++ for inclusion in fish.

#ifndef __TINYEXPR_H__
#define __TINYEXPR_H__

typedef enum {
    TE_ERROR_NONE = 0,
    TE_ERROR_UNKNOWN_VARIABLE = 1,
    TE_ERROR_MISSING_CLOSING_PAREN = 2,
    TE_ERROR_MISSING_OPENING_PAREN = 3,
    TE_ERROR_TOO_FEW_ARGS = 4,
    TE_ERROR_TOO_MANY_ARGS = 5,
    TE_ERROR_MISSING_OPERATOR = 6,
    TE_ERROR_UNEXPECTED_TOKEN = 7,
    TE_ERROR_LOGICAL_OPERATOR = 8,
    TE_ERROR_UNKNOWN = 9
} te_error_type_t;

typedef struct te_error_t {
    te_error_type_t type;
    int position;
} te_error_t;

/* Parses the input expression, evaluates it, and frees it. */
/* Returns NaN on error. */
double te_interp(const char *expression, te_error_t *error);

#endif /*__TINYEXPR_H__*/
